@@ -6,24 +6,6 @@ from typing import Awaitable
 from idem.exec.init import ExecReturn
 
 
-async def _catch_async_exec_errors(hub, ctx, coro):
-    try:
-        return await hub.pop.loop.unwrap(coro)
-    except Exception as a:
-        return _format_error(hub, ctx, a)
-
-
-def call(hub, ctx):
-    # Catch exceptions in exec modules and return the error
-    try:
-        ret = ctx.func(*ctx.args, **ctx.kwargs)
-        if asyncio.iscoroutine(ret):
-            return _catch_async_exec_errors(hub, ctx, ret)
-        return ret
-    except Exception as e:
-        return _format_error(hub, ctx, e)
-
-
 def _create_exec_return(ret, ref: str):
     try:
         return ExecReturn(
