@@ -1,4 +1,4 @@
-from dict_tools import data
+import dict_tools.data as data
 
 
 async def start(hub, name):
@@ -16,10 +16,10 @@ async def start(hub, name):
     old_seq_len = -1
     needs_post_low = True
     while True:
-        # TODO: make the errors float up
         seq = hub.idem.req.seq.init.seq(low, hub.idem.RUNS[name]["running"])
         if seq == old_seq:
-            raise Exception(f"No sequence changed for '{name}'")
+            unmet_reqs = {chunk["tag"]: chunk["unmet"] for chunk in seq.values()}
+            raise Exception(f"No sequence changed for '{name}': {unmet_reqs}")
         await getattr(hub, ref)(name, ctx, seq, low, hub.idem.RUNS[name]["running"])
         await hub.idem.resolve.render(name)
         await hub.idem.state.compile(name)
