@@ -21,10 +21,9 @@ def display(hub, data):
         state = comps[0]
         id_ = comps[1]
         fun = comps[3]
-        name = ret["name"]
-        result = ret["result"]
-        comment = ret["comment"]
-        changes = hub.output.nested.display(ret["changes"])
+        result = ret.get("result")
+        comment = ret.get("comment")
+        changes = hub.output.nested.display(ret.get("changes", {}))
         if result is True and changes:
             tcolor = fg(6)
         elif result is True:
