@@ -3,6 +3,8 @@ def post(hub, ctx):
     Conform the output of every state return to this format.
     Valid state modules must return a dictionary with these keys
     """
+    if ctx.func.__name__ == "describe":
+        return ctx.ret
     try:
         return {
             "changes": ctx.ret["changes"],
