@@ -29,6 +29,7 @@ calls, e.g. running, calling, logging, output filtering etc.
       test.fail_with_changes:
         - name: foo
 """
+import inspect
 import random
 
 TREQ = {
@@ -216,3 +217,29 @@ def configurable_test_state(
         ret["comment"] = "This is a test" if not comment else comment
 
     return ret
+
+
+def describe(hub, ctx):
+    """
+    Get the functions
+    """
+    ret = {}
+    for func in hub.states.test:
+        name = func.__name__
+        ref = f"test.{name}"
+        state_name = f"Description of {ref}"
+        ret[state_name] = {ref: []}
+
+        # Collect args
+        for arg, p in func.signature.parameters.items():
+            if arg in ("hub", "ctx", "kwargs"):
+                continue
+            elif arg == "name":
+                ret[state_name][ref].append({arg: name})
+            else:
+                if p.default == inspect._empty:
+                    ret[state_name][ref].append({arg: None})
+                else:
+                    ret[state_name][ref].append({arg: p.default})
+
+    return ret
